@@ -3,25 +3,14 @@ package PawsX::Waiter::Exception;
 use Moose;
 extends 'Throwable::Error';
 
-has name => (
-    isa      => 'Str',
-    is       => 'ro',
-    required => 1
-);
-
-has reason => (
-    isa      => 'Str',
-    is       => 'ro',
-    required => 1
-);
-
 has last_response => (
     is       => 'ro',
-    required => 1
+    isa      => 'HashRef|Undef',
+    required => 0
 );
 
-package PawsX::Exception::TimeOut;
+package PawsX::Waiter::Exception::TimeOut;
 use Moose;
 extends 'PawsX::Waiter::Exception';
 
-1;
\ No newline at end of file
+1;
